#version 330 core   

in vec4 Shadow_tex_coord;          //passed on from VS
in vec3 worldNormal;
in vec3 materialColor;
in vec3 N;
in vec3 L;

uniform sampler2DShadow shadowMap;  //shadow map is just a texture

out vec4 fragColor;       //final fragment color

void main(void) {

	vec3 ambientColor;
	vec3 diffuseColor;
	vec3 specularColor;
	float ambientIntensity;
	float diffuseIntensity;

	vec3 n = normalize(N);
	vec3 l = normalize(L);

	float diffuseLambertTerm = dot(l,n);

	//without specular
	vec3 color = materialColor;
	ambientColor = color;
	diffuseColor = vec3(1.0f, 1.0f, 0.7f);
	ambientIntensity = 0.8f;
	diffuseIntensity = 0.25f;

	//perform perspective division - homogenisierung
	vec3 tex_coords = Shadow_tex_coord.xyz/Shadow_tex_coord.w;

	//perform depth comparison
	float inShadow = texture(shadowMap, tex_coords.xyz - vec3(0,0,0.0015));

	fragColor = vec4(((ambientColor*ambientIntensity) + (diffuseColor*diffuseLambertTerm*diffuseIntensity)* inShadow) , 1.0f);
}